@@ -48,6 +48,7 @@ from .GXDLMS import GXDLMS
 from .GXDLMSAccessItem import GXDLMSAccessItem
 from .GXDLMSClient import GXDLMSClient
 from .GXDLMSConfirmedServiceError import GXDLMSConfirmedServiceError
+from .GXDLMSExceptionResponse import GXDLMSExceptionResponse
 from .GXDLMSConnectionEventArgs import GXDLMSConnectionEventArgs
 from .GXDLMSConverter import GXDLMSConverter
 from .GXDLMSException import GXDLMSException
@@ -112,5 +113,8 @@ from .GXUInt8 import GXUInt8
 from .GXUInt16 import GXUInt16
 from .GXUInt32 import GXUInt32
 from .GXUInt64 import GXUInt64
-
+from .GXFloat32 import GXFloat32
+from .GXFloat64 import GXFloat64
+from .GXIntEnum import GXIntEnum
+from .GXIntFlag import GXIntFlag
 name = "gurux_dlms"
