@@ -36,7 +36,6 @@ from .IGXDLMSBase import IGXDLMSBase
 from ..enums import ErrorCode
 from ..internal._GXCommon import _GXCommon
 from ..GXByteBuffer import GXByteBuffer
-from ..GXDateTime import GXDateTime
 from ..enums import ObjectType, DataType
 from .enums import AutoAnswerMode, AutoAnswerStatus
 
@@ -146,20 +145,20 @@ class GXDLMSAutoAnswer(GXDLMSObject, IGXDLMSBase):
                     #  Count
                     buff.setUInt8(2)
                     #  Start time
-                    _GXCommon.setData(buff, DataType.OCTET_STRING, it.getKey())
+                    _GXCommon.setData(settings, buff, DataType.OCTET_STRING, it.getKey())
                     #  End time
-                    _GXCommon.setData(buff, DataType.OCTET_STRING, it.value)
+                    _GXCommon.setData(settings, buff, DataType.OCTET_STRING, it.value)
             ret = buff.array()
         elif e.index == 4:
-            ret = self.status.value
+            ret = self.status
         elif e.index == 5:
             ret = self.numberOfCalls
         elif e.index == 6:
             buff = GXByteBuffer()
             buff.setUInt8(DataType.STRUCTURE)
             _GXCommon.setObjectCount(2, buff)
-            _GXCommon.setData(buff, DataType.UINT8, self.numberOfRingsInListeningWindow)
-            _GXCommon.setData(buff, DataType.UINT8, self.numberOfRingsOutListeningWindow)
+            _GXCommon.setData(settings, buff, DataType.UINT8, self.numberOfRingsInListeningWindow)
+            _GXCommon.setData(settings, buff, DataType.UINT8, self.numberOfRingsOutListeningWindow)
             ret = buff.array()
         else:
             e.error = ErrorCode.READ_WRITE_DENIED
@@ -177,8 +176,8 @@ class GXDLMSAutoAnswer(GXDLMSObject, IGXDLMSBase):
             self.listeningWindow = []
             if e.value:
                 for item in e.value:
-                    start = _GXCommon.changeType(item[0], DataType.DATETIME)
-                    end = _GXCommon.changeType(item[1], DataType.DATETIME)
+                    start = _GXCommon.changeType(settings, item[0], DataType.DATETIME)
+                    end = _GXCommon.changeType(settings, item[1], DataType.DATETIME)
                     self.listeningWindow.append((start, end))
         elif e.index == 4:
             self.status = e.value
@@ -198,8 +197,8 @@ class GXDLMSAutoAnswer(GXDLMSObject, IGXDLMSBase):
         self.listeningWindow = []
         if reader.isStartElement("ListeningWindow", True):
             while reader.isStartElement("Item", True):
-                start = GXDateTime(reader.readElementContentAsString("Start"))
-                end = GXDateTime(reader.readElementContentAsString("End"))
+                start = reader.readElementContentAsDateTime("Start")
+                end = reader.readElementContentAsDateTime("End")
                 self.listeningWindow.append((start, end))
             reader.readEndElement("ListeningWindow")
         self.status = reader.readElementContentAsInt("Status")
@@ -208,18 +207,16 @@ class GXDLMSAutoAnswer(GXDLMSObject, IGXDLMSBase):
         self.numberOfRingsOutListeningWindow = reader.readElementContentAsInt("NumberOfRingsOutListeningWindow")
 
     def save(self, writer):
-        if self.mode:
-            writer.writeElementString("Mode", int(self.mode))
+        writer.writeElementString("Mode", int(self.mode))
+        writer.writeStartElement("ListeningWindow")
         if self.listeningWindow:
-            writer.writeStartElement("ListeningWindow")
             for k, v in self.listeningWindow:
                 writer.writeStartElement("Item")
-                writer.writeElementString("Start", k.toFormatString())
-                writer.writeElementString("End", v.toFormatString())
+                writer.writeElementString("Start", k)
+                writer.writeElementString("End", v)
                 writer.writeEndElement()
-            writer.writeEndElement()
-        if self.status:
-            writer.writeElementString("Status", int(self.status))
+        writer.writeEndElement()
+        writer.writeElementString("Status", int(self.status))
         writer.writeElementString("NumberOfCalls", self.numberOfCalls)
         writer.writeElementString("NumberOfRingsInListeningWindow", self.numberOfRingsInListeningWindow)
         writer.writeElementString("NumberOfRingsOutListeningWindow", self.numberOfRingsOutListeningWindow)
